@@ -39,19 +39,19 @@ class UsersAPI(API):
         If ``None``, then one will be setup based on other parameters.
     users_api : :class:`fastapi_users:fastapi_users.FastAPIUsers` or None
         A FastAPIUsers object to setup routes with. If ``None``, one will be setup using the params.
-    use_auth_router : bool
+    enable_auth_router : bool
         Whether to include the Fast API Users api route.
-    use_register_router : bool
+    enable_register_router : bool
         Whether to include the Fast API Users register route.
-    use_verify_router : bool
+    enable_verify_router : bool
         Whether to include the Fast API Users verify route.
-    use_reset_password_router : bool
+    enable_reset_password_router : bool
         Whether to include the Fast API Users reset password route.
-    use_users_router : bool
+    enable_users_router : bool
         Whether to include the Fast API Users users route.
-    use_jwt_auth : bool
+    enable_jwt_auth : bool
         Whether to use JWT auth or not.
-    use_cookie_auth : bool
+    enable_cookie_auth : bool
         Whether to use cookie auth or not.
     setup_startup : bool
         Whether to setup a startup event to connect databases.
@@ -114,9 +114,9 @@ class UsersAPI(API):
     async_database : :class:`databases:databases.Database` or None
         Async database object from ``databases``. If ``None``, one will be created from database connection params.
     get_user_db : func or None
-        Function for getting the FastAPI Users DB object. If ``None``, one will be setup from params. See ``FastAPI Users database config <https://fastapi-users.github.io/fastapi-users/configuration/databases/sqlalchemy/>`_.
+        Function for getting the FastAPI Users DB object. If ``None``, one will be setup from params. See `FastAPI Users database config <https://fastapi-users.github.io/fastapi-users/configuration/databases/sqlalchemy/>`_.
     get_user_manager : func or None
-        Function for getting the FastAPI UserManager object. If ``None``, one will be setup from params. See ``FastAPI Users UserManager <https://fastapi-users.github.io/fastapi-users/configuration/user-manager/>`_.
+        Function for getting the FastAPI UserManager object. If ``None``, one will be setup from params. See `FastAPI Users UserManager <https://fastapi-users.github.io/fastapi-users/configuration/user-manager/>`_.
     cookie_auth : :class:`fastapi_users:fastapi_users.authentication.CookieAuthentication` or None
         A cookie authentication object from FastAPI Users. See `CookieAuthentication <https://fastapi-users.github.io/fastapi-users/configuration/authentication/cookie/>`_.
     jwt_auth : :class:`fastapi_users:fastapi_users.authentication.JWTAuthentication` or None
@@ -152,7 +152,7 @@ class UsersAPI(API):
     log_warnings : bool
         Whether to log warnings or not.
     *args, **kwargs
-        Additional arguments passed to :class:`fastapi_users:fastapi_users.FastAPIUsers`.
+        Additional arguments passed to :class:`msdss_base_api:msdss_base_api.core.API`.
 
     Attributes
     ----------
@@ -198,13 +198,13 @@ class UsersAPI(API):
         port='5432',
         database='msdss',
         users_api=None,
-        use_auth_router=True,
-        use_register_router=True,
-        use_verify_router=True,
-        use_reset_password_router=True,
-        use_users_router=True,
-        use_jwt_auth=True,
-        use_cookie_auth=False,
+        enable_auth_router=True,
+        enable_register_router=True,
+        enable_verify_router=True,
+        enable_reset_password_router=True,
+        enable_users_router=True,
+        enable_jwt_auth=True,
+        enable_cookie_auth=False,
         setup_startup=True,
         setup_shutdown=True,
         auth_router_auth='jwt',
@@ -273,7 +273,7 @@ class UsersAPI(API):
         database_key='MSDSS_DATABASE_NAME',
         log_warnings=True,
         *args, **kwargs):
-        super().__init__()
+        super().__init__(*args, **kwargs)
 
         # (UserAPI_env) Load env vars
         has_env = env_exists(file_path=env_file, key_path=key_path)
@@ -311,9 +311,9 @@ class UsersAPI(API):
         jwt_auth = [jwt_auth] if not isinstance(jwt_auth, list) else jwt_auth
         cookie_auth = [cookie_auth] if not isinstance(cookie_auth, list) else cookie_auth
         auth = []
-        if use_jwt_auth:
+        if enable_jwt_auth:
             auth = auth + jwt_auth
-        if use_cookie_auth:
+        if enable_cookie_auth:
             auth = auth + cookie_auth
         auth = [a for a in auth if a is not None]
         
@@ -329,12 +329,11 @@ class UsersAPI(API):
             User,
             UserCreate,
             UserUpdate,
-            UserDB,
-            *args, **kwargs
+            UserDB
         ) if users_api is None else users_api
 
         # (UsersAPI_router_auth) Add auth router
-        if use_auth_router:
+        if enable_auth_router:
 
             # (UsersAPI_router_auth_method) Set method of auth for route
             if auth_router_auth == 'jwt':
@@ -352,23 +351,23 @@ class UsersAPI(API):
                     return await auth_router_auth.get_login_response(user, response, UserManager)
 
             # (UsersAPI_router_auth_add) Add auth route
-            self.app.include_router(auth_router, **auth_router_include_kwargs)
+            self.add_router(auth_router, **auth_router_include_kwargs)
 
         # (UsersAPI_router_register) Add register router
-        if use_register_router:
-            self.app.include_router(users_api.get_register_router(**register_router_kwargs), **register_router_include_kwargs)
+        if enable_register_router:
+            self.add_router(users_api.get_register_router(**register_router_kwargs), **register_router_include_kwargs)
 
         # (UsersAPI_router_verify) Add verify router
-        if use_verify_router:
-            self.app.include_router(users_api.get_verify_router(**verify_router_kwargs), **verify_router_include_kwargs)
+        if enable_verify_router:
+            self.add_router(users_api.get_verify_router(**verify_router_kwargs), **verify_router_include_kwargs)
         
         # (UsersAPI_router_reset) Add reset password router
-        if use_reset_password_router:
-            self.app.include_router(users_api.get_reset_password_router(**reset_password_router_kwargs), **reset_password_router_include_kwargs)
+        if enable_reset_password_router:
+            self.add_router(users_api.get_reset_password_router(**reset_password_router_kwargs), **reset_password_router_include_kwargs)
 
         # (UsersAPI_router_reset) Add reset password router
-        if use_users_router:
-            self.app.include_router(users_api.get_users_router(**users_router_kwargs), **users_router_include_kwargs)
+        if enable_users_router:
+            self.add_router(users_api.get_users_router(**users_router_kwargs), **users_router_include_kwargs)
 
         # (UserAPI_events_startup) Setup app startup
         if setup_startup:
